==> gthumb-3.0.2p1.tgz: include/gthumb-3.0/gthumb/gth-enum-types.h <==



#ifndef GTH_ENUM_TYPES_H
#define GTH_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "dom.h" */
GType dom_error_enum_get_type (void);
#define GTH_TYPE_ERROR_ENUM (dom_error_enum_get_type())
/* enumerations from "gio-utils.h" */
GType gth_list_flags_get_type (void);
#define GTH_TYPE_LIST_FLAGS (gth_list_flags_get_type())
/* enumerations from "gnome-desktop-thumbnail.h" */
GType gnome_desktop_thumbnail_size_get_type (void);
#define GTH_TYPE_DESKTOP_THUMBNAIL_SIZE (gnome_desktop_thumbnail_size_get_type())
/* enumerations from "gsignature.h" */
GType g_signature_enc_get_type (void);
#define GTH_TYPE_SIGNATURE_ENC (g_signature_enc_get_type())
/* enumerations from "gth-browser.h" */
GType gth_action_get_type (void);
#define GTH_TYPE_ACTION (gth_action_get_type())
/* enumerations from "gth-error.h" */
GType gth_error_code_get_type (void);
#define GTH_TYPE_ERROR_CODE (gth_error_code_get_type())
/* enumerations from "gth-file-list.h" */
GType gth_file_list_type_get_type (void);
#define GTH_TYPE_FILE_LIST_TYPE (gth_file_list_type_get_type())
/* enumerations from "gth-file-view.h" */
GType gth_visibility_get_type (void);
#define GTH_TYPE_VISIBILITY (gth_visibility_get_type())
GType gth_file_view_renderer_type_get_type (void);
#define GTH_TYPE_FILE_VIEW_RENDERER_TYPE (gth_file_view_renderer_type_get_type())
/* enumerations from "gth-filter.h" */
GType gth_limit_type_get_type (void);
#define GTH_TYPE_LIMIT_TYPE (gth_limit_type_get_type())
/* enumerations from "gth-grid-view.h" */
GType gth_cursor_movement_get_type (void);
#define GTH_TYPE_CURSOR_MOVEMENT (gth_cursor_movement_get_type())
GType gth_drop_position_get_type (void);
#define GTH_TYPE_DROP_POSITION (gth_drop_position_get_type())
GType gth_selection_change_get_type (void);
#define GTH_TYPE_SELECTION_CHANGE (gth_selection_change_get_type())
/* enumerations from "gth-histogram.h" */
GType gth_histogram_channel_get_type (void);
#define GTH_TYPE_HISTOGRAM_CHANNEL (gth_histogram_channel_get_type())
/* enumerations from "gth-histogram-view.h" */
GType gth_histogram_mode_get_type (void);
#define GTH_TYPE_HISTOGRAM_MODE (gth_histogram_mode_get_type())
GType gth_histogram_scale_get_type (void);
#define GTH_TYPE_HISTOGRAM_SCALE (gth_histogram_scale_get_type())
/* enumerations from "gth-image.h" */
GType gth_image_format_get_type (void);
#define GTH_TYPE_IMAGE_FORMAT (gth_image_format_get_type())
/* enumerations from "gth-image-preloader.h" */
GType gth_load_policy_get_type (void);
#define GTH_TYPE_LOAD_POLICY (gth_load_policy_get_type())
/* enumerations from "gth-image-selector.h" */
GType gth_selector_type_get_type (void);
#define GTH_TYPE_SELECTOR_TYPE (gth_selector_type_get_type())
/* enumerations from "gth-image-viewer.h" */
GType gth_zoom_quality_get_type (void);
#define GTH_TYPE_ZOOM_QUALITY (gth_zoom_quality_get_type())
GType gth_fit_get_type (void);
#define GTH_TYPE_FIT (gth_fit_get_type())
GType gth_zoom_change_get_type (void);
#define GTH_TYPE_ZOOM_CHANGE (gth_zoom_change_get_type())
GType gth_transp_type_get_type (void);
#define GTH_TYPE_TRANSP_TYPE (gth_transp_type_get_type())
GType gth_check_type_get_type (void);
#define GTH_TYPE_CHECK_TYPE (gth_check_type_get_type())
GType gth_check_size_get_type (void);
#define GTH_TYPE_CHECK_SIZE (gth_check_size_get_type())
/* enumerations from "gth-metadata.h" */
GType gth_metadata_type_get_type (void);
#define GTH_TYPE_METADATA_TYPE (gth_metadata_type_get_type())
GType gth_metadata_flags_get_type (void);
#define GTH_TYPE_METADATA_FLAGS (gth_metadata_flags_get_type())
/* enumerations from "gth-metadata-provider.h" */
GType gth_metadata_write_flags_get_type (void);
#define GTH_TYPE_METADATA_WRITE_FLAGS (gth_metadata_write_flags_get_type())
/* enumerations from "gth-monitor.h" */
GType gth_monitor_event_get_type (void);
#define GTH_TYPE_MONITOR_EVENT (gth_monitor_event_get_type())
/* enumerations from "gth-overwrite-dialog.h" */
GType gth_overwrite_response_get_type (void);
#define GTH_TYPE_OVERWRITE_RESPONSE (gth_overwrite_response_get_type())
/* enumerations from "gth-task.h" */
GType gth_task_error_enum_get_type (void);
#define GTH_TYPE_TASK_ERROR_ENUM (gth_task_error_enum_get_type())
/* enumerations from "gth-test.h" */
GType gth_match_get_type (void);
#define GTH_TYPE_MATCH (gth_match_get_type())
GType gth_test_op_get_type (void);
#define GTH_TYPE_TEST_OP (gth_test_op_get_type())
/* enumerations from "gth-test-chain.h" */
GType gth_match_type_get_type (void);
#define GTH_TYPE_MATCH_TYPE (gth_match_type_get_type())
/* enumerations from "gth-test-simple.h" */
GType gth_test_data_type_get_type (void);
#define GTH_TYPE_TEST_DATA_TYPE (gth_test_data_type_get_type())
/* enumerations from "gth-user-dir.h" */
GType gth_dir_get_type (void);
#define GTH_TYPE_DIR (gth_dir_get_type())
/* enumerations from "gtk-utils.h" */
GType gth_action_flags_get_type (void);
#define GTH_TYPE_ACTION_FLAGS (gth_action_flags_get_type())
/* enumerations from "pixbuf-cache.h" */
GType pixbuf_cache_channel_get_type (void);
#define GTH_TYPE_CACHE_CHANNEL (pixbuf_cache_channel_get_type())
/* enumerations from "typedefs.h" */
GType gth_click_policy_get_type (void);
#define GTH_TYPE_CLICK_POLICY (gth_click_policy_get_type())
GType gth_direction_get_type (void);
#define GTH_TYPE_DIRECTION (gth_direction_get_type())
GType gth_toolbar_style_get_type (void);
#define GTH_TYPE_TOOLBAR_STYLE (gth_toolbar_style_get_type())
GType gth_transform_get_type (void);
#define GTH_TYPE_TRANSFORM (gth_transform_get_type())
GType gth_unit_get_type (void);
#define GTH_TYPE_UNIT (gth_unit_get_type())
GType gth_metric_get_type (void);
#define GTH_TYPE_METRIC (gth_metric_get_type())
GType gth_aspect_ratio_get_type (void);
#define GTH_TYPE_ASPECT_RATIO (gth_aspect_ratio_get_type())
GType gth_overwrite_mode_get_type (void);
#define GTH_TYPE_OVERWRITE_MODE (gth_overwrite_mode_get_type())
GType gth_grid_type_get_type (void);
#define GTH_TYPE_GRID_TYPE (gth_grid_type_get_type())
G_END_DECLS

#endif /* GTH_ENUM_TYPES_H */

==> gthumb-3.2.8.tgz: include/gthumb-3.2/gthumb/gth-enum-types.h <==



#ifndef GTH_ENUM_TYPES_H
#define GTH_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "dom.h" */
GType dom_error_enum_get_type (void);
#define GTH_TYPE_ERROR_ENUM (dom_error_enum_get_type())
/* enumerations from "gio-utils.h" */
GType gth_list_flags_get_type (void);
#define GTH_TYPE_LIST_FLAGS (gth_list_flags_get_type())
/* enumerations from "gnome-desktop-thumbnail.h" */
GType gnome_desktop_thumbnail_size_get_type (void);
#define GTH_TYPE_DESKTOP_THUMBNAIL_SIZE (gnome_desktop_thumbnail_size_get_type())
/* enumerations from "gsignature.h" */
GType g_signature_enc_get_type (void);
#define GTH_TYPE_SIGNATURE_ENC (g_signature_enc_get_type())
/* enumerations from "gth-browser.h" */
GType gth_action_get_type (void);
#define GTH_TYPE_ACTION (gth_action_get_type())
/* enumerations from "gth-color-scale.h" */
GType gth_color_scale_type_get_type (void);
#define GTH_TYPE_COLOR_SCALE_TYPE (gth_color_scale_type_get_type())
/* enumerations from "gth-error.h" */
GType gth_error_code_get_type (void);
#define GTH_TYPE_ERROR_CODE (gth_error_code_get_type())
/* enumerations from "gth-file-list.h" */
GType gth_file_list_mode_get_type (void);
#define GTH_TYPE_FILE_LIST_MODE (gth_file_list_mode_get_type())
/* enumerations from "gth-file-view.h" */
GType gth_visibility_get_type (void);
#define GTH_TYPE_VISIBILITY (gth_visibility_get_type())
GType gth_file_view_renderer_type_get_type (void);
#define GTH_TYPE_FILE_VIEW_RENDERER_TYPE (gth_file_view_renderer_type_get_type())
/* enumerations from "gth-filter.h" */
GType gth_limit_type_get_type (void);
#define GTH_TYPE_LIMIT_TYPE (gth_limit_type_get_type())
/* enumerations from "gth-grid-view.h" */
GType gth_cursor_movement_get_type (void);
#define GTH_TYPE_CURSOR_MOVEMENT (gth_cursor_movement_get_type())
GType gth_drop_position_get_type (void);
#define GTH_TYPE_DROP_POSITION (gth_drop_position_get_type())
GType gth_selection_change_get_type (void);
#define GTH_TYPE_SELECTION_CHANGE (gth_selection_change_get_type())
/* enumerations from "gth-histogram.h" */
GType gth_histogram_channel_get_type (void);
#define GTH_TYPE_HISTOGRAM_CHANNEL (gth_histogram_channel_get_type())
/* enumerations from "gth-histogram-view.h" */
GType gth_histogram_mode_get_type (void);
#define GTH_TYPE_HISTOGRAM_MODE (gth_histogram_mode_get_type())
GType gth_histogram_scale_get_type (void);
#define GTH_TYPE_HISTOGRAM_SCALE (gth_histogram_scale_get_type())
/* enumerations from "gth-image.h" */
GType gth_image_format_get_type (void);
#define GTH_TYPE_IMAGE_FORMAT (gth_image_format_get_type())
/* enumerations from "gth-image-preloader.h" */
GType gth_load_policy_get_type (void);
#define GTH_TYPE_LOAD_POLICY (gth_load_policy_get_type())
/* enumerations from "gth-image-selector.h" */
GType gth_selector_type_get_type (void);
#define GTH_TYPE_SELECTOR_TYPE (gth_selector_type_get_type())
/* enumerations from "gth-image-viewer.h" */
GType gth_zoom_quality_get_type (void);
#define GTH_TYPE_ZOOM_QUALITY (gth_zoom_quality_get_type())
GType gth_fit_get_type (void);
#define GTH_TYPE_FIT (gth_fit_get_type())
GType gth_zoom_change_get_type (void);
#define GTH_TYPE_ZOOM_CHANGE (gth_zoom_change_get_type())
GType gth_transp_type_get_type (void);
#define GTH_TYPE_TRANSP_TYPE (gth_transp_type_get_type())
GType gth_check_type_get_type (void);
#define GTH_TYPE_CHECK_TYPE (gth_check_type_get_type())
GType gth_check_size_get_type (void);
#define GTH_TYPE_CHECK_SIZE (gth_check_size_get_type())
/* enumerations from "gth-metadata.h" */
GType gth_metadata_type_get_type (void);
#define GTH_TYPE_METADATA_TYPE (gth_metadata_type_get_type())
GType gth_metadata_flags_get_type (void);
#define GTH_TYPE_METADATA_FLAGS (gth_metadata_flags_get_type())
/* enumerations from "gth-metadata-provider.h" */
GType gth_metadata_write_flags_get_type (void);
#define GTH_TYPE_METADATA_WRITE_FLAGS (gth_metadata_write_flags_get_type())
/* enumerations from "gth-monitor.h" */
GType gth_monitor_event_get_type (void);
#define GTH_TYPE_MONITOR_EVENT (gth_monitor_event_get_type())
/* enumerations from "gth-overwrite-dialog.h" */
GType gth_overwrite_response_get_type (void);
#define GTH_TYPE_OVERWRITE_RESPONSE (gth_overwrite_response_get_type())
/* enumerations from "gth-sidebar.h" */
GType gth_sidebar_state_get_type (void);
#define GTH_TYPE_SIDEBAR_STATE (gth_sidebar_state_get_type())
/* enumerations from "gth-task.h" */
GType gth_task_error_enum_get_type (void);
#define GTH_TYPE_TASK_ERROR_ENUM (gth_task_error_enum_get_type())
/* enumerations from "gth-test.h" */
GType gth_match_get_type (void);
#define GTH_TYPE_MATCH (gth_match_get_type())
GType gth_test_op_get_type (void);
#define GTH_TYPE_TEST_OP (gth_test_op_get_type())
/* enumerations from "gth-test-chain.h" */
GType gth_match_type_get_type (void);
#define GTH_TYPE_MATCH_TYPE (gth_match_type_get_type())
/* enumerations from "gth-test-simple.h" */
GType gth_test_data_type_get_type (void);
#define GTH_TYPE_TEST_DATA_TYPE (gth_test_data_type_get_type())
/* enumerations from "gth-user-dir.h" */
GType gth_dir_get_type (void);
#define GTH_TYPE_DIR (gth_dir_get_type())
/* enumerations from "gtk-utils.h" */
GType gth_action_flags_get_type (void);
#define GTH_TYPE_ACTION_FLAGS (gth_action_flags_get_type())
/* enumerations from "pixbuf-cache.h" */
GType pixbuf_cache_channel_get_type (void);
#define GTH_TYPE_CACHE_CHANNEL (pixbuf_cache_channel_get_type())
/* enumerations from "typedefs.h" */
GType gth_click_policy_get_type (void);
#define GTH_TYPE_CLICK_POLICY (gth_click_policy_get_type())
GType gth_direction_get_type (void);
#define GTH_TYPE_DIRECTION (gth_direction_get_type())
GType gth_toolbar_style_get_type (void);
#define GTH_TYPE_TOOLBAR_STYLE (gth_toolbar_style_get_type())
GType gth_transform_get_type (void);
#define GTH_TYPE_TRANSFORM (gth_transform_get_type())
GType gth_unit_get_type (void);
#define GTH_TYPE_UNIT (gth_unit_get_type())
GType gth_metric_get_type (void);
#define GTH_TYPE_METRIC (gth_metric_get_type())
GType gth_aspect_ratio_get_type (void);
#define GTH_TYPE_ASPECT_RATIO (gth_aspect_ratio_get_type())
GType gth_overwrite_mode_get_type (void);
#define GTH_TYPE_OVERWRITE_MODE (gth_overwrite_mode_get_type())
GType gth_grid_type_get_type (void);
#define GTH_TYPE_GRID_TYPE (gth_grid_type_get_type())
G_END_DECLS

#endif /* GTH_ENUM_TYPES_H */
